/*
Copyright 2011 Johan Maasing

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package nu.zoom.gal.progress.desktop;

import java.util.UUID;

import nu.zoom.gal.progress.Progress;
import nu.zoom.swing.desktop.Workbench;

/**
 * An implementation of the Progress interface. Displays progress in the zoom.nu desktop
 * status bar.
 * 
 * @author "Johan Maasing" &lt;johan@zoom.nu&gt;
 * 
 */
public class ProgressImpl implements Progress {
	private final Workbench workbench;

	public ProgressImpl(final Workbench workbench) {
		super();
		this.workbench = workbench;
	}

	/**
	 * @author Johan Maasing
	 * 
	 */
	public final class TaskID implements Progress.TaskID {
		private final UUID id;

		public TaskID() {
			this.id = UUID.randomUUID();
		}

		@Override
		public int hashCode() {
			return id.hashCode();
		}

		@Override
		public boolean equals(Object obj) {
			return id.equals(obj);
		}

		@Override
		public String toString() {
			return id.toString();
		}
	}

	@Override
	public nu.zoom.gal.progress.Progress.TaskID createTask() {
		return new TaskID();
	}

	@Override
	public void deleteTask(nu.zoom.gal.progress.Progress.TaskID taskID) {
		workbench.stopWorkIndicator();
	}

	@Override
	public void setIndeterminate(nu.zoom.gal.progress.Progress.TaskID taskID) {
		workbench.startWorkIndicator();
	}

	@Override
	public void setMaximum(nu.zoom.gal.progress.Progress.TaskID taskID) {
	}

	@Override
	public void setValue(nu.zoom.gal.progress.Progress.TaskID taskID) {
	}

	@Override
	public void setMessage(nu.zoom.gal.progress.Progress.TaskID taskID, CharSequence message) {
		workbench.setStatusbarMessage(message != null ? message.toString() : "");
	}

}
